netapp_ontap.models.storage_bridge_sas_ports API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_bridge_sas_ports`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageBridgeSasPortsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageBridgeSasPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cable: StorageBridgeSasPortsCable GET POST PATCH`

    The cable field of the storage_bridge_sas_ports.

  `data_rate_capability: float GET POST PATCH`

    Bridge SAS port data rate capability, in Gbps

  `enabled: bool GET POST PATCH`

    Indicates whether a bridge SAS port is enabled.

  `id: Size GET POST PATCH`

    Bridge SAS port index

  `negotiated_data_rate: float GET POST PATCH`

    Bridge SAS port negotiated data rate, in Gbps

  `phy_1: StorageBridgeSasPortsPhy1 GET POST PATCH`

    The phy_1 field of the storage_bridge_sas_ports.

  `phy_2: StorageBridgeSasPortsPhy2 GET POST PATCH`

    The phy_2 field of the storage_bridge_sas_ports.

  `phy_3: StorageBridgeSasPortsPhy3 GET POST PATCH`

    The phy_3 field of the storage_bridge_sas_ports.

  `phy_4: StorageBridgeSasPortsPhy4 GET POST PATCH`

    The phy_4 field of the storage_bridge_sas_ports.

  `state: str GET POST PATCH`

    Bridge SAS port state

    Valid choices:

    - error
    - online
    - offline
  `wwn: str GET POST PATCH`

    Bridge SAS port world wide name

    Example: 2100001086a54100